<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>IGU per aplicar diversos ajustos útils</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>engega brillantor-safata del sistema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>obre amb la pestanya de visualització oberta. Vàlid només amb l&apos;escriptori Xfce</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Obre directament amb la pestanya de tema. Vàlid amb els escriptoris Xfce i Fluxbox </translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Finestra principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brillantor per programari (xrandr) </translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Llum de fons per maquinari</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt; </translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="56"/>
        <location filename="../defaultlook.cpp" line="81"/>
        <location filename="../defaultlook.cpp" line="631"/>
        <location filename="../defaultlook.cpp" line="650"/>
        <location filename="../defaultlook.cpp" line="659"/>
        <location filename="../defaultlook.cpp" line="706"/>
        <location filename="../defaultlook.cpp" line="714"/>
        <location filename="../defaultlook.cpp" line="741"/>
        <location filename="../defaultlook.cpp" line="744"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalitza el plafó&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="159"/>
        <source>Panel</source>
        <translation>Plafó </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configura el comportament de finestres i dreceres&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Gestor de Finestres</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalitzeu l&apos;aspecte de l&apos;escriptori&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Aspecte </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Backup current panel configuration</source>
        <translation>Còpia de seguretat de la configuració del plafó</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="440"/>
        <location filename="../defaultlook.ui" line="485"/>
        <location filename="../defaultlook.ui" line="640"/>
        <location filename="../defaultlook.ui" line="965"/>
        <location filename="../defaultlook.ui" line="972"/>
        <location filename="../defaultlook.ui" line="979"/>
        <location filename="../defaultlook.ui" line="1050"/>
        <location filename="../defaultlook.ui" line="1336"/>
        <location filename="../defaultlook.ui" line="1645"/>
        <location filename="../defaultlook.ui" line="1798"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="303"/>
        <location filename="../defaultlook.ui" line="363"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="191"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Afecta tots els plafons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="266"/>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Affects 1st panel</source>
        <translation>Afecta al 1r plafó </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Botons de les finestres&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Restore default panel</source>
        <translation>Restaura el plafó per omissió</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="330"/>
        <source>Restore backup panel configuration</source>
        <translation>Restaura la configuració del plafó</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="383"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="388"/>
        <location filename="../defaultlook.ui" line="1619"/>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="241"/>
        <source>Display panel vertically</source>
        <translation>Mostra el plafó vertical</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Llista de tasques&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="221"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>Bottom</source>
        <translation>A sota </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="226"/>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="184"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Mode acoblador&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="167"/>
        <source>Display panel horizontally</source>
        <translation>Mostra el plafó hoitzontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="177"/>
        <source>Volume</source>
        <translation>Volum </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="198"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Defineix el connector de la llista de tasques a:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Escalat dels connectors del Plafó&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="323"/>
        <source>Power Manager</source>
        <translation>Gestor d&apos;Energia</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <source>Set Scales</source>
        <translation>Defineix l&apos;escalat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike és el connector de l&apos;acoblador  modern per al quadre.  Window Buttons és la clàssica llista de tasques sense prestacions d&apos;acoblador.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="464"/>
        <source>Theme</source>
        <translation>Tema </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="472"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icones&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="508"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Esmena el quadre d&apos;entrada HexChat al tema fosc</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="515"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="522"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Ajusta alguns camps de llocs web en usar el tema fosc</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="525"/>
        <source>Firefox dark theme tweak</source>
        <translation>Esmena el tema fosc per Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="532"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gestor de finestres&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Temes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="546"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aplicació&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Desa els paràmetres actuals com a Conjunt de Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Remove User Theme Set</source>
        <translation>Elimina el conjunt de Tema d&apos;Usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Theme Options</source>
        <translation>Opcions de Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="616"/>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="626"/>
        <location filename="../defaultlook.ui" line="667"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="660"/>
        <source>Transparency and shadow options</source>
        <translation>Opcions de transparència i ombres</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Edita directament compton.conf a l&apos;editor de text</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="677"/>
        <source>Edit compton.conf</source>
        <translation>Edita compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;canviant el mode VBlank pot alleujar alguns problemes d&apos;estrips de pantalla. Vegeu l&apos;ajuda per més informació.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <source>auto</source>
        <translation>automàtic</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="743"/>
        <source>glx</source>
        <translation>GLX</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="748"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="753"/>
        <source>off</source>
        <translation>no </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="779"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositor Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="792"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paràmetres de Xfce Compositor&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>Xfwm Settings</source>
        <translation>Paràmetres de Xfwm </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Arrenca l&apos;eina de configuració Compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="809"/>
        <source>Compton settings</source>
        <translation>Paràmetres de Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="823"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="831"/>
        <source>Hardware Backlight</source>
        <translation>Llum de fons per maquinari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustos de Pantalla&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Trieu Pantalla per als ajustos de xrandr </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="875"/>
        <source>Resolution</source>
        <translation>Resolució</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="882"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Desat per cada pantalla&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="885"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="892"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brillantor per programari (xrandr) </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="899"/>
        <location filename="../defaultlook.ui" line="996"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="906"/>
        <source>GTK scaling</source>
        <translation>Escalat GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="926"/>
        <source>xrandr Scaling</source>
        <translation>Escalat xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <source>Config Options</source>
        <translation>Opcions de configuració</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <location filename="../defaultlook.ui" line="1302"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activa clic únic al Gestor de Fitxers Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1137"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(també desactiva les decoracions del costat client de les aplicacions Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1081"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   nota: per hibernar, cal una swap  &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1088"/>
        <location filename="../defaultlook.ui" line="1708"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostra les finestres de tots els espais de treball al plafó</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1102"/>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>Thunar windows always open in split view</source>
        <translation>Finestres del Thunar sempre obertes en vista dividida</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activa &apos;hiberna&apos; al Menú de Sortida</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1109"/>
        <source>Enable single-click on desktop</source>
        <translation>Activa clic únic a l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1030"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Desactiva el truncament de noms de fitxer llargs a l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1037"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostra els botons d&apos;acció del fitxer de diàleg GTK a sota dels diàlegs </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1095"/>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Reinicia les accions de Thunar amb el botó dret als valors del sistema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1130"/>
        <source>Enable Desktop Zoom </source>
        <translation>Activa el Zoom de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1116"/>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Vista dividida del Thunar oberta en horitzontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1147"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostra el percentatge a les notificacions quan sigui possible</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1157"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1165"/>
        <source>Reset DefaultDock</source>
        <translation>Reinicia l&apos;acoblador per omissió</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paràmetres de l&apos;acoblador&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1180"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>On</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1185"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Off</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1203"/>
        <source>Manage Tint2 Panel</source>
        <translation>Gestiona el panell Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1214"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1288"/>
        <location filename="../defaultlook.ui" line="1541"/>
        <source>Autohide</source>
        <translation>Auto-amaga</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1295"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Reinicia TOTS els paràmetres de Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1309"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Reinicia el menú del Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1316"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>Placement</source>
        <translation>Posició</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1323"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icones de l&apos;escriptori&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Toggle icon captions</source>
        <translation>Canvia els títols de les icones</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Afegeix nous ítems al menú per omissió, si n&apos;hi ha, al menú fluxbox existent.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1464"/>
        <source>Upgrade existing menu entries</source>
        <translation>Actualitza les entrades actuals del menú</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>On Hover</source>
        <translation>En mantenir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Toggle desktop icons</source>
        <translation>Canvia les icones de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1507"/>
        <location filename="../defaultlook.ui" line="1656"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reinicia als valors per omissió&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1527"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paràmetres de la barra d&apos;eines&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1534"/>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1548"/>
        <source>Show Toolbar</source>
        <translation>Mostra la Barra d&apos;Eines</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1578"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1668"/>
        <source>Workspace</source>
        <translation>Espai de treball</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1675"/>
        <source>Enable single-click</source>
        <translation>Activa un-sol-clic</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Reinicia KDE/Plasma per omissió</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1718"/>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1823"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activa el muntatge de discos interns per qualsevol usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1816"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usa el l&apos;opció del controlador radeon sense estrips</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1809"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          NOTA: s&apos;ha fet còpia de seguretat del fitxer actual /etc/X11/xorg.conf.d/20-amd.conf al directori d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1871"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          NOTA: s&apos;ha fet còpia de seguretat del fitxer actual /etc/X11/xorg.conf.d/20-radeon.conf al directori d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1864"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usa les Client Side Decorations (CSD) a les aplicacions GTK3 que hi siguin compatibles (cal reinici de sessió)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1733"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;cal reiniciar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1736"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Activa els adaptadors Bluetooth en arrencar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTA: es farà còpia de seguretat del fitxer /etc/X11/xorg.conf.d/20-intel.conf al directori d&apos;usuari</translation>
    </message>
    <message>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation type="vanished">Usa el controlador libinput del ratolí tàctil en comptes del controlador synaptics (cal reiniciar) </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1771"/>
        <source>Password for administrative tasks:</source>
        <translation>Contrasenya d&apos;administrador: </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1830"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Useu el controlador intel en comptes del controlador &quot;modesetting&quot; (cal reiniciar)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1778"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usa l&apos;opció AMDGPU sense estrips</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reinicia Lightdm (pantalla d&apos;entrada) al tema per omissió</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1764"/>
        <source>Root</source>
        <translation>Arrel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1743"/>
        <source>Enable kernel sandbox</source>
        <translation>Activa l&apos;entorn de proves (sandbox)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1785"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt instal·la els paquets addicionals &quot;recomanats&quot; com a dependències</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1750"/>
        <source>Automatic generation of fluxbox applications menu after package installation, removal, and updates</source>
        <translation>Generació automàtica del menú d&apos;aplicacions a Fluxbox després de la instal·lació, eliminació o actualització de paquets, </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1940"/>
        <source>About</source>
        <translation>Quant a </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1951"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1968"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1971"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1978"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1998"/>
        <source>Xfce Settings</source>
        <translation>Paràmetres de Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="57"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--commutador de pantalla vàlid només per Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="140"/>
        <source>Style</source>
        <translation>Estil</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>About MX Tweak</source>
        <translation>Quant a MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="632"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplicació per al parametratge ràpid del tema IU per omissió</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="635"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="636"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="660"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Acabat! Firefox potser necessita tornar a arrencar per veure els canvis</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>Plese remove special characters</source>
        <translation>Si us plau, eviteu els caràcters especials</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>from file name</source>
        <translation>del nom del fitxer</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="714"/>
        <source>File name already exists.  Choose another name</source>
        <translation>El nom del fitxer ja hi és. Trieu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="742"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>El fitxer no és un arxiu tar.xz vàlid</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="745"/>
        <source>Archive does not contain a panel config</source>
        <translation>L&apos;arxiu no conté la configuració d&apos;un panell</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="931"/>
        <source>Panel settings</source>
        <translation>Paràmetres del plafó</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="932"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>S&apos;ha fet còpia de seguretat dels vostres paràmetres del plafó en un fitxer amagat anomenat .restore al vostre directori d&apos;usuari (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1713"/>
        <source>settings</source>
        <translation>paràmetres</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2053"/>
        <source>Choose a theme set</source>
        <translation>Trieu un conjunt de temes</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Elimina el conjunt de Tema d&apos;Usuari</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nou Conjunt de Temes</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Entreu un nom per al nou Conjunt de Temes</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Botons de les finestres</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aparença&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Mostra les etiquetes dels botons</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Mostra botons plans</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Mostra l&apos;ansa </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordenació:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Marca de temps</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Agrupa el títol i la marca de temps</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Títol de la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Agrupa el títol i el títol de la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Cap, permet arrossegar i deixar anar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportament&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Agrupament de finestres:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Acció del clic del mig:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Res</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Tanca la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimitza la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaura les finestres minimitzades a l&apos;espai de treball actual</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Dibuixa el marc de la finestra en passar per sobre d&apos;un botó</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Canvia de finestra amb la roda del ratolí</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtratge&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostra les finestres de tots els espais de treball</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Mostra només les finestres minimitzades</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Mostra les finestres de tots els monitors</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Finestra Emergent</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Finestra en moviment</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustos d&apos;opacitat&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Decoracions de finestra</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostra ombres sota l&apos;acoblador de finestres</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostra ombres sota les finestres emergents</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Finestres mentre es redimensionen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostra ombres sota les finestres normals</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustos destacats&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostra la vista prèvia de finestres en lloc d&apos;icones quan es fa rotació</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Mostra finestres superposades de mida normal directament</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Finestres inactives</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronitza el dibuix amb l&apos;esborrat vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Paràmetres del compositor Xfwm</translation>
    </message>
</context>
</TS>
